@@ -50,7 +50,9 @@ public abstract class AbstractWorkspaceServiceAccount<
   public static final String VIEW_ROLE_NAME = "workspace-view";
   public static final String METRICS_ROLE_NAME = "workspace-metrics";
   public static final String SECRETS_ROLE_NAME = "workspace-secrets";
+  public static final String CONFIGMAPS_ROLE_NAME = "workspace-configmaps";
   public static final String CREDENTIALS_SECRET_NAME = "workspace-credentials-secret";
+  public static final String PREFERENCES_CONFIGMAP_NAME = "workspace-preferences-configmap";
 
   protected final String namespace;
   protected final String serviceAccountName;
@@ -163,6 +165,17 @@ public abstract class AbstractWorkspaceServiceAccount<
             singletonList(""),
             Arrays.asList("get", "patch")),
         serviceAccountName + "-secrets");
+
+    // preferences-configmap role
+    ensureRoleWithBinding(
+        k8sClient,
+        buildRole(
+            CONFIGMAPS_ROLE_NAME,
+            singletonList("configmaps"),
+            singletonList(PREFERENCES_CONFIGMAP_NAME),
+            singletonList(""),
+            Arrays.asList("get", "patch")),
+        serviceAccountName + "-configmaps");
   }
 
   private void ensureRoleWithBinding(Client k8sClient, R role, String bindingName) {
