@@ -13,9 +13,9 @@ package org.eclipse.che.api.factory.server.github;
 
 import static org.eclipse.che.api.factory.server.DevfileToApiExceptionMapper.toApiException;
 
+import jakarta.validation.constraints.NotNull;
 import java.io.IOException;
 import javax.inject.Inject;
-import javax.validation.constraints.NotNull;
 import org.eclipse.che.api.core.ApiException;
 import org.eclipse.che.api.core.NotFoundException;
 import org.eclipse.che.api.factory.server.ScmFileResolver;
