@@ -34,6 +34,7 @@ import org.eclipse.che.api.factory.server.scm.exception.ScmCommunicationExceptio
 import org.eclipse.che.api.factory.server.scm.exception.ScmUnauthorizedException;
 import org.eclipse.che.commons.subject.Subject;
 import org.eclipse.che.commons.subject.SubjectImpl;
+import org.eclipse.che.inject.ConfigurationException;
 import org.eclipse.che.security.oauth.OAuthAPI;
 import org.mockito.Mock;
 import org.mockito.testng.MockitoTestNGListener;
@@ -59,7 +60,8 @@ public class GitlabOAuthTokenFetcherTest {
     WireMock.configureFor("localhost", wireMockServer.port());
     wireMock = new WireMock("localhost", wireMockServer.port());
     oAuthTokenFetcher =
-        new GitlabOAuthTokenFetcher(wireMockServer.url("/"), "http://che.api", oAuthAPI);
+        new GitlabOAuthTokenFetcher(
+            wireMockServer.url("/"), wireMockServer.url("/"), "http://che.api", oAuthAPI);
   }
 
   @AfterMethod
@@ -133,6 +135,27 @@ public class GitlabOAuthTokenFetcherTest {
     assertNotNull(token);
   }
 
+  @Test(
+      expectedExceptions = ConfigurationException.class,
+      expectedExceptionsMessageRegExp =
+          "GitLab OAuth integration endpoint must be present in registered GitLab endpoints list.")
+  public void shouldThrowConfigurationExceptionIfOauthEndpointNotInTheList() throws Exception {
+    new GitlabOAuthTokenFetcher(
+        wireMockServer.url("/"), "http://foo.bar", "http://che.api", oAuthAPI);
+  }
+
+  @Test(
+      expectedExceptions = ScmCommunicationException.class,
+      expectedExceptionsMessageRegExp =
+          "OAuth 2 is not configured for SCM provider \\[gitlab\\]. For details, refer "
+              + "the documentation in section of SCM providers configuration.")
+  public void shouldThrowScmCommunicationExceptionWhenNoOauthIsConfigured() throws Exception {
+    Subject subject = new SubjectImpl("Username", "id1", "token", false);
+    GitlabOAuthTokenFetcher localFetcher =
+        new GitlabOAuthTokenFetcher(wireMockServer.url("/"), null, "http://che.api", oAuthAPI);
+    localFetcher.fetchPersonalAccessToken(subject, wireMockServer.url("/"));
+  }
+
   @Test
   public void shouldValidatePersonalToken() throws Exception {
     stubFor(
@@ -148,7 +171,7 @@ public class GitlabOAuthTokenFetcherTest {
             wireMockServer.baseUrl(),
             "cheUser",
             "username",
-            "userId",
+            "1",
             "token-name",
             "tid-23434",
             "token123");
