@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2012-2021 Red Hat, Inc.
+ * Copyright (c) 2012-2022 Red Hat, Inc.
  * This program and the accompanying materials are made
  * available under the terms of the Eclipse Public License 2.0
  * which is available at https://www.eclipse.org/legal/epl-2.0/
@@ -87,6 +87,11 @@ public class DevfileSchemaValidatorTest {
       {"devfile/devfile_v2-1-0_just_schemaVersion.yaml"},
       {"devfile/devfile_v2-1-0_simple-devfile.yaml"},
       {"devfile/devfile_v2-2-0-simple-devfile.yaml"},
+      {"devfile/devfile_v2-2-0-quarkus.yaml"},
+      {"devfile/devfile_v2-2-0-basic-nodejs.yaml"},
+      {"devfile/devfile_v2-2-0-basic-python.yaml"},
+      {"devfile/devfile_v2-2-0-basic-quarkus.yaml"},
+      {"devfile/devfile_v2-2-0-basic-springboot.yaml"}
     };
   }
 
