@@ -278,8 +278,7 @@ public class MySqlTckModule extends TckModule {
     @Override
     public void createAll(Collection<? extends UserImpl> entities) throws TckRepositoryException {
       final EntityManager manager = managerProvider.get();
-      entities
-          .stream()
+      entities.stream()
           .map(
               user ->
                   new UserImpl(
